﻿/* Copyright 2013 Forex Capital Markets LLC

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use these files except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
using System;
using System.Collections.Generic;
using System.Text;

namespace GetHistPricesGUI
{
    /// <summary>
    /// The interface of an activity which may be executed in background.
    /// </summary>
    public interface IWaitableActivity
    {
        /// <summary>
        /// Gets the user-friendly name of the activity.
        /// </summary>
        string Name
        {
            get;
        }

        /// <summary>
        /// Valid after completing the activity. Gets the status.
        /// </summary>
        bool Success
        {
            get;
        }

        /// <summary>
        /// If the activity failed (see Status) then contains the error message.
        /// </summary>
        string ErrorMessage
        {
            get;
        }

        /// <summary>
        /// Starts the activity.
        /// </summary>
        /// <param name="form">The callback</param>
        /// <returns>True if started. Callback's OnActivityCompleted method is not
        ///     called if returns false.</returns>
        bool StartActivity(IWaitableActivityCallback callback);
    }
}
