﻿/* Copyright 2013 Forex Capital Markets LLC

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use these files except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
using System;
using System.Collections.Generic;
using System.Text;

namespace GetHistPricesGUI
{
    /// <summary>
    /// Login activity.
    /// </summary>
    class LoginActivity : IWaitableActivity
    {
        private bool mSuccess;
        private string mErrorMessage;
        private IWaitableActivityCallback mCallback;
        private LoginParams mLoginParams;
        private PriceAPIController mPriceAPIController;

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="loginParams">The login parameters.</param>
        /// <param name="controller">The price controller.</param>
        public LoginActivity(LoginParams loginParams, PriceAPIController controller)
        {
            mLoginParams = loginParams;
            mPriceAPIController = controller;
        }

        #region IWaitableActivity methods

        public string Name
        {
            get
            {
                return Properties.Resources.LoginActivityName;
            }
        }

        public bool Success
        {
            get
            {
                return mSuccess;
            }
        }

        public string ErrorMessage
        {
            get
            {
                return mErrorMessage;
            }
        }

        public bool StartActivity(IWaitableActivityCallback callback)
        {
            mCallback = callback;

            mPriceAPIController.OnStateChange += new PriceAPIController_StateChange(PriceAPIController_StateChange);
            mPriceAPIController.OnErrorEvent += new PriceAPIController_Error(PriceAPIController_Error);

            mPriceAPIController.initialize(mLoginParams.Login, mLoginParams.Password, mLoginParams.URL,
                mLoginParams.Connection, "History");

            return true;
        }

        #endregion

        #region Event handlers

        private void PriceAPIController_Error(string error)
        {
            mSuccess = false;
            mErrorMessage = error;

            mPriceAPIController.OnStateChange -= new PriceAPIController_StateChange(PriceAPIController_StateChange);
            mPriceAPIController.OnErrorEvent -= new PriceAPIController_Error(PriceAPIController_Error);

            mCallback.OnActivityCompleted();
        }

        private void PriceAPIController_StateChange(bool isReady)
        {
            if (isReady)
            {
                mSuccess = true;

                mPriceAPIController.OnStateChange -= new PriceAPIController_StateChange(PriceAPIController_StateChange);
                mPriceAPIController.OnErrorEvent -= new PriceAPIController_Error(PriceAPIController_Error);

                mCallback.OnActivityCompleted();
            }
        }

        #endregion
    }
}
