/* Copyright 2013 Forex Capital Markets LLC

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use these files except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
using System;
using System.Collections.Generic;
using System.Text;

namespace GetHistPricesGUI
{
    /// <summary>
    /// GetHistory request parameters.
    /// </summary>
    class GetHistoryParams
    {
        /// <summary>
        /// Weekend data modes.
        /// </summary>
        public enum WeekendData
        { 
            Hide = 0,
            Show = 1,
            MergeIntoMonday = 2
        }

        #region Properties

        /// <summary>
        /// Gets/sets the symbol.
        /// </summary>
        public string Symbol;

        /// <summary>
        /// Gets/sets the period.
        /// </summary>
        public string Period;

        /// <summary>
        /// Gets/sets the weekend data mode.
        /// </summary>
        public WeekendData WeekendDataMode;

        /// <summary>
        /// Gets/sets the From date. Returns ZERODATE if not defined.
        /// </summary>
        public DateTime FromDate;

        /// <summary>
        /// Gets/sets the To date. Returns ZERODATE if not defined.
        /// </summary>
        public DateTime ToDate;

        /// <summary>
        /// Gets/sets the count.
        /// </summary>
        public int Count;

        #endregion

        /// <summary>
        /// Loads default parameters from the program settings.
        /// </summary>
        public void Load()
        {
            Symbol = Properties.Settings.Default.Symbol;
            Period = Properties.Settings.Default.Period;
            WeekendDataMode = (WeekendData)Properties.Settings.Default.WeekendData;
            FromDate = Properties.Settings.Default.FromDate;
            ToDate = Properties.Settings.Default.ToDate;
            Count = Properties.Settings.Default.Count;
        }

        /// <summary>
        /// Saves GetHistory request parameters to the program settings.
        /// These parameters become default parameters.
        /// </summary>
        public void Save()
        {
            Properties.Settings.Default.Symbol = Symbol;
            Properties.Settings.Default.Period = Period;
            Properties.Settings.Default.WeekendData = (int)WeekendDataMode;
            Properties.Settings.Default.FromDate = FromDate;
            Properties.Settings.Default.ToDate = ToDate;
            Properties.Settings.Default.Count = Count;

            Properties.Settings.Default.Save();
        }
    }
}
