﻿/* Copyright 2013 Forex Capital Markets LLC

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use these files except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace GetHistPricesGUI
{
    /// <summary>
    /// The login form.
    /// </summary>
    partial class LoginForm : Form
    {
        private LoginParams mModel;
        private PriceAPIController mPriceAPIController;

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="controller">The price controller.</param>
        public LoginForm(PriceAPIController controller)
        {
            InitializeComponent();

            mPriceAPIController = controller;

            mModel = new LoginParams();
            mModel.Load();
            UpdateView();

            if (textBoxLogin.Text.Length > 0)
                textBoxPassword.Select();

            UpdateControlsState();
        }

        private void buttonClose_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void textBoxLogin_TextChanged(object sender, EventArgs e)
        {
            UpdateControlsState();
        }

        private void textBoxPassword_TextChanged(object sender, EventArgs e)
        {
            UpdateControlsState();
        }

        private void comboBoxConnection_TextChanged(object sender, EventArgs e)
        {
            UpdateControlsState();
        }

        private void textBoxURL_TextChanged(object sender, EventArgs e)
        {
            UpdateControlsState();
        }

        private void buttonLogin_Click(object sender, EventArgs e)
        {
            UpdateModel();
            mModel.Save();

            LoginActivity activity = new LoginActivity(mModel, mPriceAPIController);
            WaitForm form = new WaitForm(activity);
            form.ShowDialog();
            if (activity.Success)
                this.DialogResult = DialogResult.OK;
            else
                Util.ShowError(activity.ErrorMessage);
        }

        /// <summary>
        /// Updates state of controls after some changes.
        /// </summary>
        private void UpdateControlsState()
        {
            string login = textBoxLogin.Text;
            string password = textBoxPassword.Text;
            string connection = comboBoxConnection.Text;
            string url = textBoxURL.Text;

            buttonLogin.Enabled = login.Length > 0 &&
                password.Length > 0 &&
                connection.Length > 0 &&
                url.Length > 0;
        }

        /// <summary>
        /// Update the view by the model.
        /// </summary>
        private void UpdateView()
        {
            textBoxLogin.Text = mModel.Login;
            textBoxPassword.Text = mModel.Password;
            comboBoxConnection.Text = mModel.Connection;
            textBoxURL.Text = mModel.URL;
        }

        /// <summary>
        /// Update the model by the view.
        /// </summary>
        private void UpdateModel()
        {
            mModel.Login = textBoxLogin.Text;
            mModel.Password = textBoxPassword.Text;
            mModel.Connection = comboBoxConnection.Text;
            mModel.URL = textBoxURL.Text;
        }
    }
}
