﻿/* Copyright 2013 Forex Capital Markets LLC

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use these files except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace GetHistPricesGUI
{
    /// <summary>
    /// The Wait form is shown when some activity is executing. No other actions may be 
    /// performed at this time. But sometimes the activity may be canceled. The form
    /// cannot be closed.
    /// </summary>
    public partial class WaitForm : Form, IWaitableActivityCallback
    {
        bool mWait = false;
        bool mActivityCompleted = false;
        IWaitableActivity mActivity;

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="activity">The activity to wait.</param>
        public WaitForm(IWaitableActivity activity)
        {
            InitializeComponent();
            
            mActivity = activity;
            labelAction.Text = mActivity.Name;
        }

        public new void ShowDialog()
        {
            if (!mActivity.StartActivity(this))
                return;
            if (mActivityCompleted)
                return;

            mWait = true;
            base.ShowDialog();
        }

        delegate void HideDelegate();

        #region IWaitableActivityCallback methods

        public void OnActivityCompleted()
        { 
            mWait = false;
            if (this.IsHandleCreated)
                BeginInvoke(new HideDelegate(Hide));
            else
                mActivityCompleted = true;
        }

        #endregion

        private void WaitForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (mWait)
                e.Cancel = true;
        }
    }
}
